@@ -23,14 +23,7 @@ from tmuxp.cli.load import (
     load_plugins,
     load_workspace,
 )
-from tmuxp.cli.utils import (
-    _validate_choices,
-    get_abs_path,
-    get_config_dir,
-    is_pure_name,
-    scan_config,
-    tmuxp_echo,
-)
+from tmuxp.cli.utils import get_config_dir, is_pure_name, scan_config, tmuxp_echo
 from tmuxp.config_reader import ConfigReader
 from tmuxp.workspacebuilder import WorkspaceBuilder
 
@@ -440,6 +433,164 @@ windows:
     assert pane.current_path == str(realtemp)
 
 
+if t.TYPE_CHECKING:
+    from typing_extensions import TypeAlias
+
+    ExpectedOutput: TypeAlias = t.Optional[t.Union[str, t.List[str]]]
+
+
+class CLILoadFixture(t.NamedTuple):
+    test_id: str
+    cli_args: t.List[t.Union[str, t.List[str]]]
+    config_paths: t.List[str]
+    session_names: t.List[str]
+    expected_exit_code: int
+    expected_in_out: "ExpectedOutput" = None
+    expected_not_in_out: "ExpectedOutput" = None
+    expected_in_err: "ExpectedOutput" = None
+    expected_not_in_err: "ExpectedOutput" = None
+
+
+TEST_LOAD_FIXTURES = [
+    CLILoadFixture(
+        test_id="dir-relative-dot-samedir",
+        cli_args=["load", "."],
+        config_paths=["{tmp_path}/.tmuxp.yaml"],
+        session_names=["my_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+    CLILoadFixture(
+        test_id="dir-relative-dot-slash-samedir",
+        cli_args=["load", "./"],
+        config_paths=["{tmp_path}/.tmuxp.yaml"],
+        session_names=["my_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+    CLILoadFixture(
+        test_id="dir-relative-file-samedir",
+        cli_args=["load", "./.tmuxp.yaml"],
+        config_paths=["{tmp_path}/.tmuxp.yaml"],
+        session_names=["my_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+    CLILoadFixture(
+        test_id="filename-relative-file-samedir",
+        cli_args=["load", "./my_config.yaml"],
+        config_paths=["{tmp_path}/my_config.yaml"],
+        session_names=["my_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+    CLILoadFixture(
+        test_id="configdir-session-name",
+        cli_args=["load", "my_config"],
+        config_paths=["{TMUXP_CONFIGDIR}/my_config.yaml"],
+        session_names=["my_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+    CLILoadFixture(
+        test_id="configdir-absolute",
+        cli_args=["load", "~/.config/tmuxp/my_config.yaml"],
+        config_paths=["{TMUXP_CONFIGDIR}/my_config.yaml"],
+        session_names=["my_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+    #
+    # Multiple configs
+    #
+    CLILoadFixture(
+        test_id="configdir-session-name-double",
+        cli_args=["load", "my_config", "second_config"],
+        config_paths=[
+            "{TMUXP_CONFIGDIR}/my_config.yaml",
+            "{TMUXP_CONFIGDIR}/second_config.yaml",
+        ],
+        session_names=["my_config", "second_config"],
+        expected_exit_code=0,
+        expected_in_out=None,
+        expected_not_in_out=None,
+    ),
+]
+
+
+@pytest.mark.parametrize(
+    list(CLILoadFixture._fields),
+    TEST_LOAD_FIXTURES,
+    ids=[test.test_id for test in TEST_LOAD_FIXTURES],
+)
+@pytest.mark.usefixtures("tmuxp_configdir_default")
+def test_load(
+    tmp_path: pathlib.Path,
+    tmuxp_configdir: pathlib.Path,
+    server: "Server",
+    session: Session,
+    capsys: pytest.CaptureFixture,
+    monkeypatch: pytest.MonkeyPatch,
+    test_id: str,
+    cli_args: t.List[str],
+    config_paths: t.List[str],
+    session_names: t.List[str],
+    expected_exit_code: int,
+    expected_in_out: "ExpectedOutput",
+    expected_not_in_out: "ExpectedOutput",
+    expected_in_err: "ExpectedOutput",
+    expected_not_in_err: "ExpectedOutput",
+) -> None:
+    assert server.socket_name is not None
+
+    monkeypatch.chdir(tmp_path)
+    for session_name, config_path in zip(session_names, config_paths):
+        tmuxp_config = pathlib.Path(
+            config_path.format(tmp_path=tmp_path, TMUXP_CONFIGDIR=tmuxp_configdir)
+        )
+        tmuxp_config.write_text(
+            """
+        session_name: {session_name}
+        windows:
+        - window_name: test
+          panes:
+          -
+        """.format(
+                session_name=session_name
+            ),
+            encoding="utf-8",
+        )
+
+    try:
+        cli.cli([*cli_args, "-d", "-L", server.socket_name, "-y"])
+    except SystemExit:
+        pass
+
+    result = capsys.readouterr()
+    output = "".join(list(result.out))
+
+    if expected_in_out is not None:
+        if isinstance(expected_in_out, str):
+            expected_in_out = [expected_in_out]
+        for needle in expected_in_out:
+            assert needle in output
+
+    if expected_not_in_out is not None:
+        if isinstance(expected_not_in_out, str):
+            expected_not_in_out = [expected_not_in_out]
+        for needle in expected_not_in_out:
+            assert needle not in output
+
+    for session_name in session_names:
+        assert server.has_session(session_name)
+
+
 def test_regression_00132_session_name_with_dots(
     tmp_path: pathlib.Path,
     server: "Server",
@@ -931,7 +1082,7 @@ def test_help(
         pass
     result = capsys.readouterr()
 
-    assert "usage: tmuxp [-h] [--version] [--log-level LOG_LEVEL]" in result.out
+    assert "usage: tmuxp [-h] [--version] [--log-level log-level]" in result.out
 
 
 @pytest.mark.parametrize(
@@ -1127,13 +1278,15 @@ def test_freeze_overwrite(
     assert yaml_config_path.exists()
 
 
-def test_get_abs_path(tmp_path: pathlib.Path, monkeypatch: pytest.MonkeyPatch) -> None:
+def test_resolve_behavior(
+    tmp_path: pathlib.Path, monkeypatch: pytest.MonkeyPatch
+) -> None:
     expect = str(tmp_path)
     monkeypatch.chdir(tmp_path)
-    get_abs_path("../") == os.path.dirname(expect)
-    get_abs_path(".") == expect
-    get_abs_path("./") == expect
-    get_abs_path(expect) == expect
+    pathlib.Path("../").resolve() == os.path.dirname(expect)
+    pathlib.Path(".").resolve() == expect
+    pathlib.Path("./").resolve() == expect
+    pathlib.Path(expect).resolve() == expect
 
 
 def test_get_tmuxinator_dir(monkeypatch: pytest.MonkeyPatch) -> None:
@@ -1152,16 +1305,6 @@ def test_get_teamocil_dir(monkeypatch: pytest.MonkeyPatch) -> None:
     assert get_teamocil_dir() == os.path.expanduser("~/.teamocil/")
 
 
-def test_validate_choices() -> None:
-    validate = _validate_choices(["choice1", "choice2"])
-
-    assert validate("choice1")
-    assert validate("choice2")
-
-    with pytest.raises(ValueError):
-        assert validate("choice3")
-
-
 def test_pass_config_dir_ClickPath(
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
